#!/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.6

$LastChangedRevision: 5343 $
$LastChangedDate:: 2021-12-13 15:25:29 +0100#$

This file is part of SyMSpace.

Copyright (c) 2018, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""

if __name__ == '__main__':
    """
    This script tests all component project tests

    This script needs to be run in a SyMSpace console!

    Commandline Arguments
    ---------------------

    --start_dir : str
        The search for tests starts from this directory (Optional).
        Default is the ComponentSpace root directory.


    Examples
    --------

    >>> CSyMSpace.exe run_component_tests.py

    >>> CSyMSpace.exe run_component_tests.py --start_dir "C:\\ComponentSpace\\Simulation\\Motor"

    """
    import os
    import shutil
    from symspace.osutils.pathutils import Paths
    from symspace.testing.symproject.suite import SymProjectTestSuite
    from componentspace.testing.create_tests import ComponentTestBuilder

    start_dir, test_case_options, process_options = SymProjectTestSuite.getCMDArguments(
        default_start_dir=Paths.getComponentSpaceRoot(), default_process_timeout=300)

    report_dir = ComponentTestBuilder.run_reports_dir
    output = os.path.join(report_dir, 'single_tests')
    merged_file = os.path.join(report_dir, 'merged-junit.xml')
    single_outsuffix = 'junit-tmp'  # hide the single files from the discovery of junit-files -> build-server

    if os.path.isdir(report_dir):
        shutil.rmtree(report_dir)

    suite = SymProjectTestSuite()
    prj_files = suite.findTestsFilesByPattern(start_dir, ComponentTestBuilder.get_search_pattern())
    suite.addTestsFromFiles(prj_files, **test_case_options)
    suite.runExternalXMLRunner(output, outsuffix=single_outsuffix,
                               n_max_proc=process_options['n_max_proc'],
                               timeout=process_options['timeout'])
    suite.mergeJUnitXMLFiles(merged_file, output=output, outsuffix=single_outsuffix)
